function [dxdt]=ode_dimensionless(t,x,par)

% load variables from main file
L = par(1);                     % adsorbent bed height (m)
rho_b = par(2);                 % bed density (kg/m3 = g/L)
epsilon_b = par(3);             % bed porosity (-)
d_p = par(4);                   % adsorbent particle diameter (m)
C_in = par(5);                   % inlet concentration (mg/L)
v = par(6);                     % convective flow velocity (m/h)
Bi = par(7);
q0 = par(8);
a_vr = par(9);                  % Volumetric film mass transfer coeff (1/m)
nr = par(10);                   % number of layers in the paricle
np = par(11);                   % number of planes in the column
h = par(12);                    % dx (m)
dR = par(13);                   % dr (m)    
k_F = par(14);                  % Film mass transfer coefficient (m/h)
r_p = par(15);                  % Adsorbent particle radius (m)
D_s = par(16);                  % Surface diffusion coefficient (m2/h)
D_ax = par(17);                  % Dispersion coefficient (m2/h)
freund_K = par(18);                  
freund_n = par(19);                  
Ed = par(20);                 
dispersion = par(21);
D_g = par(22);
St = par(23);


% create empty vectors to increase performance
 dXdS = zeros(np+1,1); Xs = zeros(np+1,1); dYdR = zeros(np+1,nr+1); d2YdR2 = zeros(np+1,nr+1); dXdT = zeros(np+1,1); dYdT = zeros(np+1,nr+1); d2XdS2 = zeros(np+1,1);

% turn unknown x variable into X  and Y for easy reference, note that var
% Y is a matrix in which every column is a different layer in the particle

% loading X and Y for all midplanes   % this part is only to create a blank vector
X = x(1:np+1);                       
Y = reshape(x(np+2:end),[np+1 nr+1]);   % Reshapes the x answer into a 2d matrix Y( x , r ) at current time

%Calculate values for X and Y at the boundaries based on boundary
%conditions 
Xin = 1;  %bdc 1 %JOUKE: I changed this line
Y(:,1) = Y(:,2); %bdc 2 

global globaltest  Y_glob  X_glob Y_P3

Yprev = Y(:,nr);
options = optimset('Display','off','TolFun',1e-10);
Ysol = fsolve(@(Ybound) funYbds(Ybound,Yprev,X,dR,Bi,freund_n),globaltest,options);  %bdc 3                                 %7.64 

globaltest = Ysol;

Y(:,nr+1)=Ysol;
Y_glob = Y;
X_glob = X;
Y_P3 = Yprev;

Rvect = [0 : 1/nr : 1];

% Calculate the Derivatives 

for i=1:np+1    % go through planes
    for j=2:nr   % go through layers of particle except the outer layer
    if i==1
          Xs(i) = Y(i,nr+1).^ (1/freund_n);%7.61 Fredulich isotherm
          dXdS(i)= (X(i)-Xin)/h; %JOUKE: I changed this line         
          dXdT(i) = (D_g + 1) * ( -dXdS(i) - 3 * St * ( X(i) - Xs(i) ) );
          dYdR(i,j) = ( 0.5*Y(i,j+1) - 0.5*Y(i,j-1) ) / (1/nr) ;   
          d2YdR2(i,j) = ( Y(i,j+1) - 2 * Y(i,j) + Y(i,j-1) ) / ( (1/nr)^2 );
          dYdT(i,j) = Ed * (D_g + 1) / D_g * ( d2YdR2(i,j) + 2/Rvect(j) * dYdR(i,j) );
    else
        Xs(i) = Y(i,nr+1).^ (1/freund_n);%7.61 Fredulich isotherm
        dXdS(i)= (X(i)-X(i-1))/h;
        dXdT(i) = (D_g + 1) * ( -dXdS(i) - 3 * St * ( X(i) - Xs(i) ) ); %7.59 column mass balance    
        dYdR(i,j) = ( 0.5*Y(i,j+1) - 0.5*Y(i,j-1) ) / (1/nr) ;   
        d2YdR2(i,j) = ( Y(i,j+1) - 2 * Y(i,j) + Y(i,j-1) ) / ( (1/nr)^2 ); % Forward-Time Central-Space method  
        dYdT(i,j) = Ed * (D_g + 1) / D_g * ( d2YdR2(i,j) + 2/Rvect(j) * dYdR(i,j) ); % surface diffusion (eq 7.50)
        
    end
    end 

  
end
disp(t);
dYdT = reshape(dYdT,[1 (np+1)*(nr+1)]);
dxdt=[dXdT;dYdT'];
