%function [xspan,tspan,X,Y] = worchnew(C_in, EBCT, end_T)
close all
clear all

%% Parameters
clc;clear;
tic
% Default parameters (if input arguments are not given)
if ~exist('C_in','var'); C_in = 1; end %  inlet concentration (mg/L)
if ~exist('EBCT','var'); EBCT = 20/60; end %  EBCT (h)
%if ~exist('end_T','var'); end_T = 1.333332e4; end % Time in h     % Bi=1
if ~exist('end_T','var'); end_T = 4.00e4; end % Time in h      % Bi=91

global globaltest X_glob Y_glob Y_P2 Y_P3


% Physical properties of column and GAC
L = 2;                       % adsorbent bed length (m)
rho_b = 500;                    % bed density (kg/m3 = g/L)
epsilon_b = 0.4;               % bed porosity (-)
d_p = 2e-3;                  % adsorbent particle diameter (m)
r_p = d_p/2;                    % adsorbent particle radius (m)
a_vr = 3 * (1-epsilon_b)/r_p;   % surface to volume ratio(m2/m3)
v = L /EBCT / epsilon_b; % superficial velocity (m/h)
t_r = EBCT * epsilon_b;   % effective residence time (h) = eq 6.16

% Equilibrium (data from Esther Mendoza's thesis)   Freundlich isotherm
freund_K = 60;                
freund_n = 0.3;
q0 = freund_K * C_in ^ (1/freund_n); % qs = K*cs^1/n

% Rate coefficients
dispersion = 0;                 % Incorporate dispersion (0=false, 1=true)
k_F = 1.37e-5 * 3600;                % Film mass transfer coeff (m/h)
%D_s = 2.67e-13 * 3600;  %Bi=1
D_s = 2.93e-15 * 3600;  %Bi=91

D_ax  = 400;                     % Dispersion coefficient (m2/h)

% Dimensionless parameters
D_g = q0 * rho_b / C_in / epsilon_b; % Solute distribution parameter
St = k_F * t_r * (1-epsilon_b)/(epsilon_b * r_p);
Ed = D_s * D_g * t_r / (r_p * r_p);
Bi = St/Ed;
Pe = L * v / k_F / r_p;

% Integration parameters
np = 25; %JOUKE: here we still have a very big problem. If np is not equal to nr, the results are completely off, and are not correct. Can you have a detailed look at this? 
nt = 600; %JOUKE: more timesteps, smoother results
nr = 19;
dR = 1/(nr);
h = 1/(np);
S = (1:np)/(np);
T = linspace(0,end_T,nt)/ ( t_r * (D_g+1) ); 

% Parameter container
par = [L,rho_b,epsilon_b,d_p,C_in,v,Bi,q0,a_vr,nr,np,h,dR,k_F,r_p,D_s,D_ax,freund_K, freund_n, Ed, dispersion, D_g, St];

% Initial values for ode15s
cinit = 0.00001.* ones(np+1,1);           % C in different column space (x) steps
qinit = 0.00001.* ones((np+1)*(nr+1),1);      % q in different column space (x) steps and columns particle space (r)
init = [cinit;qinit];               % results in a np+1 * nr+1 column vector that is solved at every time.
globaltest = 0.00001.*ones(np+1,1);

%% Solve using ode15s
[tspan,x] = ode15s(@(t,x) ode_dimensionless(t,x,par),T,init);
tspan = tspan*t_r*(D_g+1);
xspan = S*L;

%% Retrieve C and q from x solution vector
X = x(:,1:np+1);
Y = reshape( x(:,np+2:end) , [nt np+1 nr+1] ); % Reshapes the x answer into a 3d matrix q( t , x , r )


%% Plots
% fig1 = figure;
% title('Concentration profile in the liquid');
% movegui(fig1,'northwest');
% surf(xspan,tspan/EBCT*60,X/C_in);
% view(40,40);
% xlabel ('S (m)'); ylabel ('BV'); zlabel('X (mg/L)');
% axis([xspan(2), L, 0, end_T/EBCT*60, 0, C_in*1.15]);

fig2 = figure;
title('Breakthrough curve at different depths')
plot(tspan/EBCT,X/C_in)
xlabel ('BV'); ylabel ('X(mg/L)');
xlim( [0 end_T/EBCT]);

% fig3 = figure;
% title('Concentration profile in adsorbed phase at 4 different times');
% movegui(fig3,'north');
% for i=1:4
%     subplot(2,2,i);
%     surf(transpose((0:(nr))/(nr)),S(2:end),squeeze(Y(i*round((nt-1)/4),2:end,:)))
%     title(['Y at t=',num2str(i*round((nt-1)/4)*end_T/nt),' h']);
%     view(150,40);
%     xlabel ('R (-)'); ylabel ('S (-)'); zlabel('Y (-)');
%     axis([-inf, inf, -inf, inf, 0 , 1]);
% end

toc

% % display in the compand windows
% disp( ['Dg = ', num2str(D_g)]);
% disp( ['Ed = ', num2str(Ed)]);
% disp( ['St = ', num2str(St)]);
% disp( ['Bi = ', num2str(Bi)]);
% disp( ['Pe = ', num2str(Pe)]);
% 
% 

% C_ans = retrieve_values(tspan, xspan, C)

m = tspan/EBCT;
n = X/C_in;
z=[m,n];
% xlswrite('Bi=91',z)





% %% Mass balance
% 
%     % inflow
%     flow = 50 / EBCT; % ml / min
%     cum_time = end_T*60;
%     V_in = flow * cum_time; % in ml
%     mg_in = V_in * C_in / 1000 % in mg
% 
%     
%     % outflow
%     C_out =  X(:,end) * C_in; % mg/L
%     dt = tspan(2); % (h)
%     cumt=0;
%     for i=1:nt-1
%         mg_out(i) = dt * 60 * flow / 1000 * ( C_out(i+1) + C_out(i) ) / 2;
%     end
%     mg_out = sum(mg_out)
%     
%     % adsorbed
%     mg_ads = mg_in-mg_out
%     mg_geadsorbeerd = sum(sum( squeeze(Y(end,:,:))))*q0/nr/np*rho_b*0.05
%     % mg_ads2 = sum(sum(squeeze( Y(end,:,:) ) * q0 * 0.05 * rho_b /np/nr))
%     % average_loading_in_percent = mg_ads / 0.05 / rho_b / q0 *100
%     MB_gap = (mg_ads-mg_geadsorbeerd)/mg_in *100;
%     disp(['GAP in mb =',num2str(MB_gap)]);